import QtQuick 1.1
import SoundGen 1.0
import com.nokia.meego 1.0


Page {
    orientationLock: PageOrientation.LockPortrait
    Image {
        anchors.fill:parent
        source:"sg-bg.png"
    }
    AboutDialog {
        id:aboutDialog
    }

    Connections {
        target:platformWindow
        onActiveChanged: {
            if(!platformWindow.active)
            {
                control.stop();
            }
        }
    }

    SoundGenControl {
        id:control
        x:40
        y:40
        width:400
        height:300
        frequency:Math.round(Math.exp(frequencySlider.value))
        Rectangle {
            color:"#080810"
            anchors.fill:parent
        } 
    }

    Image {
        id:playStopImage
        anchors.top:buttonRow.bottom
        anchors.horizontalCenter:parent.horizontalCenter
        anchors.margins:20
        source: (control.soundState === SoundGenControl.PLAYING ) ? "pause.png" : "play.png"
        MouseArea {
            anchors.fill:parent
            onClicked: {
                if(control.soundState === SoundGenControl.PLAYING) {
                    control.stop()
                }
                else {
                    control.play()
                }
            }
        }
    }

    Rectangle {
        anchors.top:playStopImage.bottom
        anchors.topMargin: 20
        height:130
        anchors.horizontalCenter: parent.horizontalCenter
        width:400
        color:"black"
        id:freqMonitor
        Text {
            id:freqLabel
            anchors.centerIn: parent
            text:control.frequency
            font.pixelSize:100
            color: "green"
        }
    }

    Slider {
        id:frequencySlider
        anchors.top: freqMonitor.bottom
        minimumValue: 2.9900
        maximumValue: 9.9035
        width:parent.width
        valueIndicatorVisible: false
        value:6.086
        stepSize: 0.001
    }

    Row {
        id:buttonRow
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top:control.bottom
        anchors.topMargin: 5
        spacing: 5
        WaveButton {
            activeIcon: "sine-button-on.png"
            inactiveIcon: "sine-button.png"
            onClicked: control.setWave(SoundGenControl.SINE)
            active: control.wave == SoundGenControl.SINE
        }
        WaveButton {
            activeIcon: "square-button-on.png"
            inactiveIcon: "square-button.png"
            onClicked: control.setWave(SoundGenControl.SQUARE)
            active: control.wave == SoundGenControl.SQUARE
        }
        WaveButton {
            activeIcon: "triangle-button-on.png"
            inactiveIcon: "triangle-button.png"
            onClicked: control.setWave(SoundGenControl.TRIANGLE)
            active: control.wave == SoundGenControl.TRIANGLE
        }
        WaveButton {
            activeIcon: "saw-button-on.png"
            inactiveIcon: "saw-button.png"
            onClicked: control.setWave(SoundGenControl.SAW)
            active: control.wave == SoundGenControl.SAW
        }
    }
    Image {
        id:aboutImage
        source:"about.png"
        anchors.right:parent.right
        anchors.bottom:parent.bottom
        anchors.margins: 5
        width:50
        height:50
        MouseArea {
            anchors.fill:parent
            onClicked: {
                aboutDialog.open()
            }
        }
    }
}
